@@ -16,13 +16,13 @@ Elive::StandardV2 - Perl bindings for the Elluminate Live Standard Bridge (V2)
 
 =head1 VERSION
 
-Version 0.00_7
+Version 0.00_8
 
 ** DEVELOPER RELEASE - UNDER CONSTRUCTION **
 
 =cut
 
-our $VERSION = '0.00_7';
+our $VERSION = '0.00_8';
 
 =head1 SYNOPSIS
 
@@ -30,13 +30,13 @@ our $VERSION = '0.00_7';
     use Elive::StandardV2::Session;
     use Elive::Util;
 
-    my $session_start = Elive::Util::next_quarter_hour();
-    my $session_end = Elive::Util::next_quarter_hour( $session_start );
-
     my $connection = Elive::StandardV2->connect(
                                 'http://myserver/mysite',
                                 'some_user' => 'some_pass' );
 
+    my $session_start = Elive::Util::next_quarter_hour();
+    my $session_end = Elive::Util::next_quarter_hour( $session_start );
+
     my %session_data = (
 	sessionName   => 'My Demo Session',
 	creatorId     => $connection->user,
@@ -180,10 +180,6 @@ sub update {
     return $class->SUPER::update($data, %opt);
 }
 
-=head2 fetch
-
-=cut
-
 sub _fetch {
     my ($class, $key, %opt) = @_;
 
@@ -291,10 +287,12 @@ sub delete {
 	);
 
     my $success = @$results && $results->[0];
+
     return $self->_deleted(1)
 	if $success;
 
     carp "deletion failed(?) with 'false' status";
+    return;
 }
 
 
